/*
 * Copyright (C) 2009 Xizhi Zhu <xizhi.zhu@gmail.com>
 * Copyright (C) 2013 Sylvain Munaut <tnt@246tNt.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation,
 * or attached in the package as the LICENSE file.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 */

#ifndef __CRMD160_H__
#define __CRMD160_H__

class CRMD160
{
public:
	// Create a message digest using RIPEMD-160.
	CRMD160(int mode);

	// Reset the digest to the initial state.
	void reset();

	// Update the digest.
	void update(const char *input, int len);

	// Complete the hash computation and return the digest.
	void digest(char *out);

	// Return the length of the digest in bytes.
	int getDigestLength() const;

private:
	// Compute the digest of a single block.
	void hashBlock(const char* const in);

	int mode;

	// the chaining variables.
	unsigned int h0_;
	unsigned int h1_;
	unsigned int h2_;
	unsigned int h3_;
	unsigned int h4_;

	// the buffer to hold the last block
	char buffer_[64];

	// the length of data in the buffer
	int bufLen_;

	// the total number of data hashed
	unsigned long long total_;
};

#endif /* __CRMD160_H__ */
