/*
 * Copyright (C) 2013 Sylvain Munaut <tnt@246tNt.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdio.h>
#include <stdlib.h>

#include "crmd160.h"

void *file_load(const char *filename, int *len)
{
	FILE *fh;
	void *data;

	fh = fopen(filename, "rb");
	if (!fh)
		return NULL;

	fseek(fh, 0, SEEK_END);
	*len = ftell(fh);
	fseek(fh, 0, SEEK_SET);

	data = malloc(*len);

	fread(data, 1, *len, fh);

	fclose(fh);

	return data;
}

int main(int argc, char *argv[])
{
	void *data_buf;
	int data_len;
	CRMD160 *hash;
	char digest[20];

	if (argc != 2) {
		fprintf(stderr, "Usage: %s infile.txt\n", argv[0]);
		return -1;
	}

	data_buf = file_load(argv[1], &data_len);
	if (!data_buf) {
		fprintf(stderr, "[!] Unable to open input file\n");
		return -1;
	}

	hash = new CRMD160(1);

	hash->update((const char *)data_buf, data_len);

	hash->digest(digest);

	//printf("%s", (char*)data_buf);
	printf("Add the following line to the .cfg file : \n# CRC01 %02x%02x%02x%02x\r\n",
		digest[3] & 0xff,
		digest[2] & 0xff,
		digest[1] & 0xff,
		digest[0] & 0xff
	);

	delete hash;

	free(data_buf);

	return 0;
}
